from django.shortcuts import render, redirect
from django.http import HttpResponse
from .forms import (
    HomeForm,
    UserForm,
    NicknameForm,
    BioForm,
    KeyForm,
    ItemsThisWeekForm,
    ItemsTodayForm,
)
from .models import User, Key, ItemsThisWeek, ItemsToday


def ShowHome(request):
    if request.method == 'POST':
        form = HomeForm(request.POST)
        if form.is_valid():
            name = form.cleaned_data['name']
            #renders another HTML with the user's name and without the form
            return render(request, 'home2.html', {'name': name})

    form = HomeForm()
    return render(request, 'home.html', {'form': form})


def ShowProfile(request):
    form = UserForm()
    if User.objects.count() == 0:
        user = User( #creates the default model instance for the User Model
        nickname='Your nickname',
        bio='A short description about yourself.',
        profile_photo='default.jpg'
        )
        user.save()
    else:
        user = User.objects.get(pk=1)
    context = {
        'form': form,
        'user': user,
    }

    if request.method == 'POST':
        current = User.objects.get(pk=1) #allows us to edit current photo
        form = UserForm(request.POST, request.FILES, instance=current)
        if form.is_valid():
            form.save()
            return redirect('profile')
    return render(request, 'profile.html', context)


def ShowEditNickname(request):
    user = User.objects.get(pk=1)
    form = NicknameForm(instance=user)
    if request.method == 'POST':
        form = NicknameForm(request.POST, instance=user)
        if form.is_valid():
            form.save()
            return redirect('profile')
    return render(request, 'edit_nickname.html', {'form': form})


def ShowEditBio(request):
    user = User.objects.get(pk=1)
    form = BioForm(instance=user)
    if request.method == 'POST':
        form = BioForm(request.POST, instance=user)
        if form.is_valid():
            form.save()
            return redirect('profile')
    return render(request, 'edit_bio.html', {'form': form})


def ShowKey(request):
    key_list = Key.objects.all()
    return render(request, 'key.html', {'key_list': key_list})


def ShowAddKey(request):
    form = KeyForm()
    if request.method == 'POST':
        form = KeyForm(request.POST)
        if form.is_valid():
            form.save()
            return redirect('key')
    return render(request, 'add_key.html', {'form': form})


def ShowThisWeek(request):
    item_list = list(ItemsThisWeek.objects.all())
    if request.method == 'POST':
        for i in request.POST.keys():
            name = i # i is equal to the 'name' from request.POST
        for item in item_list:
            if str(item.id) == name:
                item.key_type.key_name = 'Task done'
                break
    return render(request, 'this_week.html', {'item_list': item_list})


def ShowAddItemTW(request):
    form = ItemsThisWeekForm()
    if request.method == 'POST':
        form = ItemsThisWeekForm(request.POST)
        if form.is_valid():
            form.save()
            return redirect('this_week')
    return render(request, 'add_itemTW.html', {'form': form})


def ShowEditItemTW(request, pk):
    item = ItemsThisWeek.objects.get(id=pk)
    form = ItemsThisWeekForm(instance=item)
    if request.method == 'POST':
        form = ItemsThisWeekForm(request.POST, instance=item)
        if form.is_valid():
            form.save()
            return redirect('this_week')
    return render(request, 'edit_itemTW.html', {'form': form})


def ShowDeleteItemTW(request, pk):
    if request.method == 'POST':
        item = ItemsThisWeek.objects.get(id=pk)
        item.delete()
        return redirect('this_week')
    return render(request, 'delete_itemTW.html')


def ShowToday(request):
    item_list = list(ItemsToday.objects.all())
    if request.method == 'POST':
        for i in request.POST.keys():
            name = i # i is equal to the 'name' from request.POST
        for item in item_list:
            if str(item.id) == name:
                item.key_type.key_name = 'Task done'
                break
    return render(request, 'today.html', {'item_list': item_list})


def ShowAddItemT(request):
    form = ItemsTodayForm()
    if request.method == 'POST':
        form = ItemsTodayForm(request.POST)
        if form.is_valid():
            form.save()
            return redirect('today')
    return render(request, 'add_itemT.html', {'form': form})


def ShowEditItemT(request, pk):
    item = ItemsToday.objects.get(id=pk)
    form = ItemsTodayForm(instance=item)
    if request.method == 'POST':
        form = ItemsTodayForm(request.POST, instance=item)
        if form.is_valid():
            form.save()
            return redirect('today')
    return render(request, 'edit_itemT.html', {'form': form})


def ShowDeleteItemT(request, pk):
    if request.method == 'POST':
        item = ItemsToday.objects.get(id=pk)
        item.delete()
        return redirect('today')
    return render(request, 'delete_itemT.html')
